@@ -1662,7 +1662,7 @@ class TpuClient(metaclass=TpuClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "TpuClient":
         return self
 
     def __exit__(self, type, value, traceback):
