@@ -48,14 +48,14 @@ class TpuGrpcTransport(TpuTransport):
         self,
         *,
         host: str = "tpu.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        channel: grpc.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        channel: Optional[grpc.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -183,8 +183,8 @@ class TpuGrpcTransport(TpuTransport):
     def create_channel(
         cls,
         host: str = "tpu.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         **kwargs,
@@ -426,6 +426,112 @@ class TpuGrpcTransport(TpuTransport):
             )
         return self._stubs["update_node"]
 
+    @property
+    def list_queued_resources(
+        self,
+    ) -> Callable[
+        [cloud_tpu.ListQueuedResourcesRequest], cloud_tpu.ListQueuedResourcesResponse
+    ]:
+        r"""Return a callable for the list queued resources method over gRPC.
+
+        Lists queued resources.
+
+        Returns:
+            Callable[[~.ListQueuedResourcesRequest],
+                    ~.ListQueuedResourcesResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_queued_resources" not in self._stubs:
+            self._stubs["list_queued_resources"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/ListQueuedResources",
+                request_serializer=cloud_tpu.ListQueuedResourcesRequest.serialize,
+                response_deserializer=cloud_tpu.ListQueuedResourcesResponse.deserialize,
+            )
+        return self._stubs["list_queued_resources"]
+
+    @property
+    def get_queued_resource(
+        self,
+    ) -> Callable[[cloud_tpu.GetQueuedResourceRequest], cloud_tpu.QueuedResource]:
+        r"""Return a callable for the get queued resource method over gRPC.
+
+        Gets details of a queued resource.
+
+        Returns:
+            Callable[[~.GetQueuedResourceRequest],
+                    ~.QueuedResource]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_queued_resource" not in self._stubs:
+            self._stubs["get_queued_resource"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/GetQueuedResource",
+                request_serializer=cloud_tpu.GetQueuedResourceRequest.serialize,
+                response_deserializer=cloud_tpu.QueuedResource.deserialize,
+            )
+        return self._stubs["get_queued_resource"]
+
+    @property
+    def create_queued_resource(
+        self,
+    ) -> Callable[[cloud_tpu.CreateQueuedResourceRequest], operations_pb2.Operation]:
+        r"""Return a callable for the create queued resource method over gRPC.
+
+        Creates a QueuedResource TPU instance.
+
+        Returns:
+            Callable[[~.CreateQueuedResourceRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "create_queued_resource" not in self._stubs:
+            self._stubs["create_queued_resource"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/CreateQueuedResource",
+                request_serializer=cloud_tpu.CreateQueuedResourceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["create_queued_resource"]
+
+    @property
+    def delete_queued_resource(
+        self,
+    ) -> Callable[[cloud_tpu.DeleteQueuedResourceRequest], operations_pb2.Operation]:
+        r"""Return a callable for the delete queued resource method over gRPC.
+
+        Deletes a QueuedResource TPU instance.
+
+        Returns:
+            Callable[[~.DeleteQueuedResourceRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_queued_resource" not in self._stubs:
+            self._stubs["delete_queued_resource"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/DeleteQueuedResource",
+                request_serializer=cloud_tpu.DeleteQueuedResourceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["delete_queued_resource"]
+
     @property
     def generate_service_identity(
         self,
@@ -592,6 +698,34 @@ class TpuGrpcTransport(TpuTransport):
             )
         return self._stubs["get_guest_attributes"]
 
+    @property
+    def simulate_maintenance_event(
+        self,
+    ) -> Callable[
+        [cloud_tpu.SimulateMaintenanceEventRequest], operations_pb2.Operation
+    ]:
+        r"""Return a callable for the simulate maintenance event method over gRPC.
+
+        Simulates a maintenance event.
+
+        Returns:
+            Callable[[~.SimulateMaintenanceEventRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "simulate_maintenance_event" not in self._stubs:
+            self._stubs["simulate_maintenance_event"] = self.grpc_channel.unary_unary(
+                "/google.cloud.tpu.v2alpha1.Tpu/SimulateMaintenanceEvent",
+                request_serializer=cloud_tpu.SimulateMaintenanceEventRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["simulate_maintenance_event"]
+
     def close(self):
         self.grpc_channel.close()
 
