@@ -18,13 +18,16 @@ from .cloud_tpu import (
     AccessConfig,
     AttachedDisk,
     CreateNodeRequest,
+    CreateQueuedResourceRequest,
     DeleteNodeRequest,
+    DeleteQueuedResourceRequest,
     GenerateServiceIdentityRequest,
     GenerateServiceIdentityResponse,
     GetAcceleratorTypeRequest,
     GetGuestAttributesRequest,
     GetGuestAttributesResponse,
     GetNodeRequest,
+    GetQueuedResourceRequest,
     GetRuntimeVersionRequest,
     GuestAttributes,
     GuestAttributesEntry,
@@ -33,16 +36,22 @@ from .cloud_tpu import (
     ListAcceleratorTypesResponse,
     ListNodesRequest,
     ListNodesResponse,
+    ListQueuedResourcesRequest,
+    ListQueuedResourcesResponse,
     ListRuntimeVersionsRequest,
     ListRuntimeVersionsResponse,
     NetworkConfig,
     NetworkEndpoint,
     Node,
     OperationMetadata,
+    QueuedResource,
+    QueuedResourceState,
     RuntimeVersion,
     SchedulingConfig,
     ServiceAccount,
     ServiceIdentity,
+    ShieldedInstanceConfig,
+    SimulateMaintenanceEventRequest,
     StartNodeRequest,
     StopNodeRequest,
     Symptom,
@@ -54,13 +63,16 @@ __all__ = (
     "AccessConfig",
     "AttachedDisk",
     "CreateNodeRequest",
+    "CreateQueuedResourceRequest",
     "DeleteNodeRequest",
+    "DeleteQueuedResourceRequest",
     "GenerateServiceIdentityRequest",
     "GenerateServiceIdentityResponse",
     "GetAcceleratorTypeRequest",
     "GetGuestAttributesRequest",
     "GetGuestAttributesResponse",
     "GetNodeRequest",
+    "GetQueuedResourceRequest",
     "GetRuntimeVersionRequest",
     "GuestAttributes",
     "GuestAttributesEntry",
@@ -69,16 +81,22 @@ __all__ = (
     "ListAcceleratorTypesResponse",
     "ListNodesRequest",
     "ListNodesResponse",
+    "ListQueuedResourcesRequest",
+    "ListQueuedResourcesResponse",
     "ListRuntimeVersionsRequest",
     "ListRuntimeVersionsResponse",
     "NetworkConfig",
     "NetworkEndpoint",
     "Node",
     "OperationMetadata",
+    "QueuedResource",
+    "QueuedResourceState",
     "RuntimeVersion",
     "SchedulingConfig",
     "ServiceAccount",
     "ServiceIdentity",
+    "ShieldedInstanceConfig",
+    "SimulateMaintenanceEventRequest",
     "StartNodeRequest",
     "StopNodeRequest",
     "Symptom",
